/*****************************************************************************
/*
/*            INSTITUTO NACIONAL PARA LA EVALUACIN DE LA EDUCACIN
/*                       DIRECCIN DE PRUEBAS Y MEDICIN
/*                           SUBDIRECCION DE ANLISIS
/*_____________________________________________________________________________
/*
/*            EXAMENES DE LA CALIDAD Y EL LOGRO EDUCATIVOS (Excale)
/*                     SEXTO GRADO DE PRIMARIA (Excale 06)
/*
/*                          **** EDUCACIN CVICA ****
/*
/*                     Ciclo escolar evaluado: 2008 - 2009
/*_____________________________________________________________________________
/*
/*
/*  PROGRAMA PARA CONSTRUIR LA BASE DE DATOS DE ALUMNOS DE EDUCACIN CVICA
/*                               EN FORMATO SAS
/*_____________________________________________________________________________
/*
/*  El programa convierte al archivo Excale06_2009_Alum_Civ.txt, el cual est en
/*  formato ASCII, en una base de datos en formato SAS. El programa realiza las
/*  siguientes tareas:
/*   - Declara formatos para algunas variables
/*   - Lee las variables del archivo en formato ASCII
/*   - Declara los valores considerados en el anlisis como perdidos (missing values)
/*
/* INSTRUCCIONES
/*  Para construir la base de datos (tabla de datos) es necesario:
/*      1) Crear una carpeta de trabajo y colocar en ella al archivo Excale06_2009_Alum_Civ.txt
/*         as como el archivo Excale06_2009_Alum_Civ.SAS (este archivo) los cules se pueden
/*         descargar del sitio web del INEE (www.inee.edu.mx).
/*      2) Modificar la primera y segunda lnea de los comandos de este archivo
/*         (libname y filename) para actualizar el nombre de la librera y el archivo
/*         de trabajo.
/*      3) Ejecutar el programa del archivo.
/*
/*  Al finalizar, se deber contar con la base de datos (tabla de datos) Excale06_2009_Alum_Civ.sas7bdat
/*
/*  Posteriormente, cuando se desee utilizar nuevamente la base Excale06_2009_Alum_Civ.sas7bdat,
/*  se deber ejecutar primero el procedimiento FORMAT ("proc FORMAT") de este programa para que
/*  SAS cargue los formatos necesarios para abrir la base.
/*
/* CONTACTO:
/*
/*      Para mayor informacin o aclaracin de dudas favor de contactar a la
/*      Subdireccin de Anlisis del Instituto
/*      Correo electrnico: excale.analisis@inee.edu.mx
/*      Tel 5482 0900 Ext. 1082
/*      Domicilio: Jos Ma. Velasco No. 101. 3er piso. Col. San Jos Insurgentes
/*                 Del. Benito Jurez. Mxico. D.F.
/*
/* FECHA DE LIBERACIN: 20 DE ABRIL DE 2012
/*
/*  ****************************************************************************/

LIBNAME  INEE  "C:\***\";
FILENAME alum  "C:\***\Excale06_2009_Alum_Civ.TXT";

PROC FORMAT;
     VALUE id_entF     1         ="Aguascalientes"
                       2         ="Baja California"
                       3         ="Baja California Sur"
                       4         ="Campeche"
                       5         ="Coahuila"
                       6         ="Colima"
                       7         ="Chiapas"
                       8         ="Chihuahua"
                       9         ="Distrito Federal"
                       10        ="Durango"
                       11        ="Guanajuato"
                       12        ="Guerrero"
                       13        ="Hidalgo"
                       14        ="Jalisco"
                       15        ="Mxico"
                       16        ="Michoacn"
                       17        ="Morelos"
                       18        ="Nayarit"
                       19        ="Nuevo Len"
                       20        ="Oaxaca"
                       21        ="Puebla"
                       22        ="Quertaro"
                       23        ="Quintana Roo"
                       24        ="San Luis Potos"
                       25        ="Sinaloa"
                       26        ="Sonora"
                       27        ="Tabasco"
                       28        ="Tamaulipas"
                       29        ="Tlaxcala"
                       30        ="Veracruz"
                       31        ="Yucatn"
                       32        ="Zacatecas";
     VALUE id_modF     1         ="Urbana Pblica"
                       2         ="Rural Pblica"
                       3         ="Educacin Indgena"
                       4         ="Curso Comunitario"
                       5         ="Privada"
                       6         ="General"
                       7         ="Tcnica"
                       8         ="Telesecundaria"
                       9         ="Privada";
     VALUE $modF       "UP"      ="Urbano Pblico"
                       "RP"      ="Rural Pblico"
                       "EI"      ="Educacin Indgena"
                       "CC"      ="Cursos Comunitarios"
                       "UPV"     ="Privados"
                       "GRAL"    ="General"
                       "TEC"     ="Tcnica"
                       "TV"      ="Telesecundaria"
                       "PRIV"    ="Privada";
     VALUE $gmF        "1"       ="Muy alto"
                       "2"       ="Alto"
                       "3"       ="Medio"
                       "4"       ="Bajo"
                       "5"       ="Muy bajo"
                       "9"       ="Perdido"
                       "NA"      ="No aplica";
     VALUE marg_urF    1         ="Alta marginacin"
                       2         ="Baja marginacin"
                       7         ="No aplica";
     VALUE sexoF       1         ="Hombre"
                       2         ="Mujer"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE edadF       99        ="Respuesta omitida";
     VALUE edadcF      1         ="Once aos o menos"
                       2         ="Doce aos"
                       3         ="Trece aos"
                       4         ="Catorce aos o ms"
                       9         ="Respuesta omitida";
     VALUE edadnF      1         ="Edad normativa"
                       2         ="Extra-edad"
                       9         ="Respuesta omitida";
     VALUE edad_acF    10        ="10 aos"
                       11        ="11 aos"
                       12        ="12 aos"
                       13        ="13 aos"
                       14        ="14 aos"
                       15        ="15 aos o ms"
                       98        ="Respuesta mltiple"
                       99        ="Respuesta omitida";
     VALUE mes_nacF    1         ="Enero"
                       2         ="Febrero"
                       3         ="Marzo"
                       4         ="Abril"
                       5         ="Mayo"
                       6         ="Junio"
                       7         ="Julio"
                       8         ="Agosto"
                       9         ="Septiembre"
                       10        ="Octubre"
                       11        ="Noviembre"
                       12        ="Diciembre"
                       98        ="Respuesta mltiple"
                       99        ="Respuesta omitida";
     VALUE docenteF    99999     ="Respuesta omitida";
     VALUE ca1_c19F    0         ="Fallo"
                       1         ="Acierto"
                       5         ="Reactivo no alcanzado (se considera como no administrado)"
                       6         ="Reactivo no administrado por error de impresin"
                       7         ="Reactivo no administrado (No se incluy en su cuadernillo de examen)";
RUN;



DATA INEE.Excale06_2009_Alum_Civ;
   LENGTH
       NACIONAL           3
       ESCUELA            4
       ID_ENT             3
       NOM_ENT            $19
       ID_MOD             3
       MOD                $4
       GM                 $2
       MARG_URB           3
       ESTRATO            $7
       ENTEST             $6
       ALUMNO             6
       ID_INSTR           $16
       SEXO               3
       EDAD               8
       EDADC              3
       EDADN              3
       EDAD_AC            3
       MES_NAC            3
       W_ALU              8
       DOCENTE            5
       PCA_01             3
       PCA_02             3
       PCA_03             3
       PCA_04             3
       PCA_05             3
       PCA_06             3
       PCA_07             3
       PCA_08             3
       PCA_09             3
       PCA_10             3
       PCA_11             3
       PCA_12             3
       PCA_13             3
       PCA_14             3
       PCA_15             3
       PCA_16             3
       PCA_17             3
       PCA_18             3
       PCB_01             3
       PCB_02             3
       PCB_03             3
       PCB_04             3
       PCB_05             3
       PCB_06             3
       PCB_07             3
       PCB_08             3
       PCB_09             3
       PCB_10             3
       PCB_11             3
       PCB_12             3
       PCB_13             3
       PCB_14             3
       PCB_15             3
       PCB_16             3
       PCB_17             3
       PCB_18             3
       PCB_19             3
       PCC_01             3
       PCC_03             3
       PCC_04             3
       PCC_05             3
       PCC_06             3
       PCC_07             3
       PCC_08             3
       PCC_09             3
       PCC_10             3
       PCC_11             3
       PCC_12             3
       PCC_13             3
       PCC_14             3
       PCC_15             3
       PCC_16             3
       PCC_17             3
       PCC_18             3
       PCC_19             3
       PV1CIV             8
       PV2CIV             8
       PV3CIV             8
       PV4CIV             8
       PV5CIV             8
       CIVNVL1            3
       CIVNVL2            3
       CIVNVL3            3
       CIVNVL4            3
       CIVNVL5            3
       CIVNVBL1           3
       CIVNVBL2           3
       CIVNVBL3           3
       CIVNVBL4           3
       CIVNVBL5           3
       WVARSTRR           3
       W_FSTR1            8
       W_FSTR2            8
       W_FSTR3            8
       W_FSTR4            8
       W_FSTR5            8
       W_FSTR6            8
       W_FSTR7            8
       W_FSTR8            8
       W_FSTR9            8
       W_FSTR10           8
       W_FSTR11           8
       W_FSTR12           8
       W_FSTR13           8
       W_FSTR14           8
       W_FSTR15           8
       W_FSTR16           8
       W_FSTR17           8
       W_FSTR18           8
       W_FSTR19           8
       W_FSTR20           8
       W_FSTR21           8
       W_FSTR22           8
       W_FSTR23           8
       W_FSTR24           8
       W_FSTR25           8
       W_FSTR26           8
       W_FSTR27           8
       W_FSTR28           8
       W_FSTR29           8
       W_FSTR30           8
       W_FSTR31           8
       W_FSTR32           8
       W_FSTR33           8
       W_FSTR34           8
       W_FSTR35           8
       W_FSTR36           8
       W_FSTR37           8
       W_FSTR38           8
       W_FSTR39           8
       W_FSTR40           8
       W_FSTR41           8
       W_FSTR42           8
       W_FSTR43           8
       W_FSTR44           8
       W_FSTR45           8
       W_FSTR46           8
       W_FSTR47           8
       W_FSTR48           8
       W_FSTR49           8
       W_FSTR50           8
       W_FSTR51           8
       W_FSTR52           8
       W_FSTR53           8
       W_FSTR54           8
       W_FSTR55           8
       W_FSTR56           8
       W_FSTR57           8
       W_FSTR58           8
       W_FSTR59           8
       W_FSTR60           8
       W_FSTR61           8
       W_FSTR62           8
       W_FSTR63           8
       W_FSTR64           8
       W_FSTR65           8
       W_FSTR66           8
       W_FSTR67           8
       W_FSTR68           8
       W_FSTR69           8
       W_FSTR70           8
       W_FSTR71           8
       W_FSTR72           8
       W_FSTR73           8
       W_FSTR74           8
       W_FSTR75           8
       W_FSTR76           8
       W_FSTR77           8
       W_FSTR78           8
       W_FSTR79           8
       W_FSTR80           8
 ;

INFILE alum MISSOVER LINESIZE = 1090;
   INPUT
       NACIONAL           1 - 1
       ESCUELA            2 - 5
       ID_ENT             6 - 7
       NOM_ENT            8 - 26
       ID_MOD            27 - 27
       MOD               28 - 31
       GM                32 - 33
       MARG_URB          34 - 34
       ESTRATO           35 - 41
       ENTEST            42 - 47
       ALUMNO            48 - 53
       ID_INSTR          54 - 69
       SEXO              70 - 70
       EDAD              71 - 81
       EDADC             82 - 82
       EDADN             83 - 83
       EDAD_AC           84 - 85
       MES_NAC           86 - 87
       W_ALU             88 - 98
       DOCENTE           99 - 103
       PCA_01           104 - 104
       PCA_02           105 - 105
       PCA_03           106 - 106
       PCA_04           107 - 107
       PCA_05           108 - 108
       PCA_06           109 - 109
       PCA_07           110 - 110
       PCA_08           111 - 111
       PCA_09           112 - 112
       PCA_10           113 - 113
       PCA_11           114 - 114
       PCA_12           115 - 115
       PCA_13           116 - 116
       PCA_14           117 - 117
       PCA_15           118 - 118
       PCA_16           119 - 119
       PCA_17           120 - 120
       PCA_18           121 - 121
       PCB_01           122 - 122
       PCB_02           123 - 123
       PCB_03           124 - 124
       PCB_04           125 - 125
       PCB_05           126 - 126
       PCB_06           127 - 127
       PCB_07           128 - 128
       PCB_08           129 - 129
       PCB_09           130 - 130
       PCB_10           131 - 131
       PCB_11           132 - 132
       PCB_12           133 - 133
       PCB_13           134 - 134
       PCB_14           135 - 135
       PCB_15           136 - 136
       PCB_16           137 - 137
       PCB_17           138 - 138
       PCB_18           139 - 139
       PCB_19           140 - 140
       PCC_01           141 - 141
       PCC_03           142 - 142
       PCC_04           143 - 143
       PCC_05           144 - 144
       PCC_06           145 - 145
       PCC_07           146 - 146
       PCC_08           147 - 147
       PCC_09           148 - 148
       PCC_10           149 - 149
       PCC_11           150 - 150
       PCC_12           151 - 151
       PCC_13           152 - 152
       PCC_14           153 - 153
       PCC_15           154 - 154
       PCC_16           155 - 155
       PCC_17           156 - 156
       PCC_18           157 - 157
       PCC_19           158 - 158
       PV1CIV           159 - 166
       PV2CIV           167 - 174
       PV3CIV           175 - 182
       PV4CIV           183 - 190
       PV5CIV           191 - 198
       CIVNVL1          199 - 199
       CIVNVL2          200 - 200
       CIVNVL3          201 - 201
       CIVNVL4          202 - 202
       CIVNVL5          203 - 203
       CIVNVBL1         204 - 204
       CIVNVBL2         205 - 205
       CIVNVBL3         206 - 206
       CIVNVBL4         207 - 207
       CIVNVBL5         208 - 208
       WVARSTRR         209 - 210
       W_FSTR1          211 - 221
       W_FSTR2          222 - 232
       W_FSTR3          233 - 243
       W_FSTR4          244 - 254
       W_FSTR5          255 - 265
       W_FSTR6          266 - 276
       W_FSTR7          277 - 287
       W_FSTR8          288 - 298
       W_FSTR9          299 - 309
       W_FSTR10         310 - 320
       W_FSTR11         321 - 331
       W_FSTR12         332 - 342
       W_FSTR13         343 - 353
       W_FSTR14         354 - 364
       W_FSTR15         365 - 375
       W_FSTR16         376 - 386
       W_FSTR17         387 - 397
       W_FSTR18         398 - 408
       W_FSTR19         409 - 419
       W_FSTR20         420 - 430
       W_FSTR21         431 - 441
       W_FSTR22         442 - 452
       W_FSTR23         453 - 463
       W_FSTR24         464 - 474
       W_FSTR25         475 - 485
       W_FSTR26         486 - 496
       W_FSTR27         497 - 507
       W_FSTR28         508 - 518
       W_FSTR29         519 - 529
       W_FSTR30         530 - 540
       W_FSTR31         541 - 551
       W_FSTR32         552 - 562
       W_FSTR33         563 - 573
       W_FSTR34         574 - 584
       W_FSTR35         585 - 595
       W_FSTR36         596 - 606
       W_FSTR37         607 - 617
       W_FSTR38         618 - 628
       W_FSTR39         629 - 639
       W_FSTR40         640 - 650
       W_FSTR41         651 - 661
       W_FSTR42         662 - 672
       W_FSTR43         673 - 683
       W_FSTR44         684 - 694
       W_FSTR45         695 - 705
       W_FSTR46         706 - 716
       W_FSTR47         717 - 727
       W_FSTR48         728 - 738
       W_FSTR49         739 - 749
       W_FSTR50         750 - 760
       W_FSTR51         761 - 771
       W_FSTR52         772 - 782
       W_FSTR53         783 - 793
       W_FSTR54         794 - 804
       W_FSTR55         805 - 815
       W_FSTR56         816 - 826
       W_FSTR57         827 - 837
       W_FSTR58         838 - 848
       W_FSTR59         849 - 859
       W_FSTR60         860 - 870
       W_FSTR61         871 - 881
       W_FSTR62         882 - 892
       W_FSTR63         893 - 903
       W_FSTR64         904 - 914
       W_FSTR65         915 - 925
       W_FSTR66         926 - 936
       W_FSTR67         937 - 947
       W_FSTR68         948 - 958
       W_FSTR69         959 - 969
       W_FSTR70         970 - 980
       W_FSTR71         981 - 991
       W_FSTR72         992 - 1002
       W_FSTR73        1003 - 1013
       W_FSTR74        1014 - 1024
       W_FSTR75        1025 - 1035
       W_FSTR76        1036 - 1046
       W_FSTR77        1047 - 1057
       W_FSTR78        1058 - 1068
       W_FSTR79        1069 - 1079
       W_FSTR80        1080 - 1090
;

   LABEL
       NACIONAL    = "Variable auxiliar para obtener promedios nacionales"
       ESCUELA     = "Identificador de la escuela"
       ID_ENT      = "Entidad federativa (identificador numrico)"
       NOM_ENT     = "Entidad federativa"
       ID_MOD      = "Estrato escolar o Modalidad educativa (identificador numrico)"
       MOD         = "Estrato escolar o Modalidad educativa"
       GM          = "Clave de Grado de Marginacin Urbano oficial/Rural (AGEB/localidad)"
       MARG_URB    = "Marginalidad Urbana"
       ESTRATO     = "Estrato de muestreo. Se construy con ENTIDAD, MODALIDAD Y MARGINALIDAD. No es comn a todas las tablas pues en algunos casos se colapsaron registros"
       ENTEST      = "Estratos del diseo muestral con el que se estiman los parmetros y errores estndar (Entidad federativa-Modalidad)"
       ALUMNO      = "Identificador del alumno"
       ID_INSTR    = "Identificador del cuadernillo de examen"
       SEXO        = "Sexo del alumno"
       EDAD        = "Edad del alumno al mes de mayo de 2009, en aos (al momento de la aplicacin)"
       EDADC       = "Edad del alumno al mes de mayo de 2009, codificada (al momento de la aplicacin)"
       EDADN       = "Edad normativa"
       EDAD_AC     = "Edad en aos cumplidos (al momento de la aplicacin)"
       MES_NAC     = "Mes de nacimiento del alumno (al momento de la aplicacin)"
       W_ALU       = "Peso muestral o ponderador del alumno"
       DOCENTE     = "Identificador del docente que imparte clases al alumno"
       PCA_01      = "Reactivo 47. Identificar las caractersticas de los componentes del Estado"
       PCA_02      = "Reactivo 48. Identificar a la soberana como poder popular"
       PCA_03      = "Reactivo 27. Reconocer  a la democracia como forma de vida"
       PCA_04      = "Reactivo 2. Identificar caractersticas de procesos electorales democrticos"
       PCA_05      = "Reactivo 55. Identificar las funciones de la Procuradura General de la Repblica"
       PCA_06      = "Reactivo 38. Identificar elementos de las Constituciones de 1824 y 1857 presentes en la actual"
       PCA_07      = "Reactivo 35. Identificar algunas obligaciones impuestas en el artculo 3o constitucional"
       PCA_08      = "Reactivo 39. Reconocer las instancias que pueden modificar la Constitucin"
       PCA_09      = "Reactivo 22. Identificar el respeto a la diversidad fsica y cultural"
       PCA_10      = "Reactivo 14. Reconocer formas de actuar ante opiniones diversas"
       PCA_11      = "Reactivo 54. Identificar prcticas de discriminacin racial"
       PCA_12      = "Reactivo 20. Identificar rasgos de la convivencia social armnica"
       PCA_13      = "Reactivo 25. Reconocer a la participacin ciudadana como factor de cambio"
       PCA_14      = "Reactivo 26. Reconocer los principios que orientan las relaciones de Mxico con otros pases"
       PCA_15      = "Reactivo 30. Identificar elementos de la Doctrina Estrada"
       PCA_16      = "Reactivo 7. Reconocer a la paz como producto del ejercicio de valores"
       PCA_17      = "Reactivo 18. Reconocer el valor de la justicia"
       PCA_18      = "Reactivo 3. Reconocer el valor de la legalidad"
       PCB_01      = "Reactivo 41. Reconocer a la repblica como forma de gobierno en Mxico"
       PCB_02      = "Reactivo 32. Identificar las caractersticas de una repblica federal"
       PCB_03      = "Reactivo 43. Distinguir las funciones de los Poderes de la Unin"
       PCB_04      = "Reactivo 15. Reconocer la importancia de la divisin de poderes"
       PCB_05      = "Reactivo 45. Reconocer a los actores que pueden presentar iniciativas de ley"
       PCB_06      = "Reactivo 19. Identificar la relacin entre sociedad democrtica y respeto a los Derechos Humanos"
       PCB_07      = "Reactivo 1. Identificar alguno de los Derechos Humanos"
       PCB_08      = "Reactivo 37. Identificar situaciones en que se ejerce el derecho de amparo"
       PCB_09      = "Reactivo 31. Identificar alguna demanda poltica de la Revolucin mexicana en la Constitucin"
       PCB_10      = "Reactivo 8. Identificar algunas obligaciones impuestas en el artculo 123 constitucional"
       PCB_11      = "Reactivo 51. Identificar razones que llevan a modificar las leyes"
       PCB_12      = "Reactivo 23. Identificar a la tolerancia ante la libertad de creencias"
       PCB_13      = "Reactivo 29. Identificar a la tolerancia ante costumbres diversas"
       PCB_14      = "Reactivo 50. Identificar prcticas de discriminacin social"
       PCB_15      = "Reactivo 6. Identificar prcticas de discriminacin sexual"
       PCB_16      = "Reactivo 12. Reconocer al dilogo como mecanismo para establecer acuerdos entre individuos"
       PCB_17      = "Reactivo 49. Identificar las funciones de la Organizacin de las Naciones Unidas"
       PCB_18      = "Reactivo 44. Reconocer el valor de la responsabilidad"
       PCB_19      = "Reactivo 9. Reconocer el valor de la honestidad"
       PCC_01      = "Reactivo 17. Identificar los componentes del Estado"
       PCC_03      = "Reactivo 13. Reconocer la importancia de la Constitucin  para la federacin"
       PCC_04      = "Reactivo 53. Identificar razones histricas que llevaron a modificar la Constitucin de 1917"
       PCC_05      = "Reactivo 21. Identificar principios de la democracia"
       PCC_06      = "Reactivo 24. Reconocer la importancia de los procesos electorales para la integracin de los gobiernos"
       PCC_07      = "Reactivo 52. Identificar las funciones de los partidos polticos"
       PCC_08      = "Reactivo 36. Identificar la importancia de la participacin ciudadana"
       PCC_09      = "Reactivo 40. Identificar las funciones de la Suprema Corte de Justicia"
       PCC_10      = "Reactivo 46. Identificar los propsitos del Congreso Constituyente de 1917"
       PCC_11      = "Reactivo 33. Identificar algunas aspiraciones del pueblo en la Revolucin mexicana"
       PCC_12      = "Reactivo 28. Identificar algunos derechos impuestos en el artculo 27 constitucional"
       PCC_13      = "Reactivo 16. Identificar diversas condiciones de vida ante un desarrollo desigual en el pas"
       PCC_14      = "Reactivo 34. Reconocer a Mxico como un pas diverso"
       PCC_15      = "Reactivo 42. Identificar razones que llevan a establecer normas"
       PCC_16      = "Reactivo 11. Reconocer al dilogo como mecanismo para establecer acuerdos entre naciones"
       PCC_17      = "Reactivo 5. Reconocer el valor de la solidaridad"
       PCC_18      = "Reactivo 4. Reconocer el valor del respeto"
       PCC_19      = "Reactivo 10. Reconocer el valor de la libertad"
       PV1CIV      = "Primer valor plausible de Educacin Cvica"
       PV2CIV      = "Segundo valor plausible de Educacin Cvica"
       PV3CIV      = "Tercer valor plausible de Educacin Cvica"
       PV4CIV      = "Cuarto valor plausible de Educacin Cvica"
       PV5CIV      = "Quinto valor plausible de Educacin Cvica"
       CIVNVL1     = "Nivel de logro en Educacin Cvica. Asociado a PV1CIV. (Cuatro niveles)"
       CIVNVL2     = "Nivel de logro en Educacin Cvica. Asociado a PV2CIV. (Cuatro niveles)"
       CIVNVL3     = "Nivel de logro en Educacin Cvica. Asociado a PV3CIV. (Cuatro niveles)"
       CIVNVL4     = "Nivel de logro en Educacin Cvica. Asociado a PV4CIV. (Cuatro niveles)"
       CIVNVL5     = "Nivel de logro en Educacin Cvica. Asociado a PV5CIV. (Cuatro niveles)"
       CIVNVBL1    = "Identifica si el alumno pertenece al menos al nivel bsico de logro en Educacin Cvica. Asociado a PV1CIV."
       CIVNVBL2    = "Identifica si el alumno pertenece al menos al nivel bsico de logro en Educacin Cvica. Asociado a PV2CIV."
       CIVNVBL3    = "Identifica si el alumno pertenece al menos al nivel bsico de logro en Educacin Cvica. Asociado a PV3CIV."
       CIVNVBL4    = "Identifica si el alumno pertenece al menos al nivel bsico de logro en Educacin Cvica. Asociado a PV4CIV."
       CIVNVBL5    = "Identifica si el alumno pertenece al menos al nivel bsico de logro en Educacin Cvica. Asociado a PV5CIV."
       WVARSTRR    = "Identificador del pseudoestrato (1 a 80) definido para el clculo de errores estndar con el mtodo de remuestreo BRR"
       W_FSTR1     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR2     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR3     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR4     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR5     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR6     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR7     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR8     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR9     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR10    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR11    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR12    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR13    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR14    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR15    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR16    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR17    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR18    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR19    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR20    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR21    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR22    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR23    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR24    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR25    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR26    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR27    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR28    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR29    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR30    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR31    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR32    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR33    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR34    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR35    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR36    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR37    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR38    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR39    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR40    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR41    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR42    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR43    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR44    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR45    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR46    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR47    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR48    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR49    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR50    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR51    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR52    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR53    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR54    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR55    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR56    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR57    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR58    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR59    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR60    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR61    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR62    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR63    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR64    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR65    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR66    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR67    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR68    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR69    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR70    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR71    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR72    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR73    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR74    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR75    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR76    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR77    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR78    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR79    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR80    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
;

   FORMAT
       NACIONAL           1.
       ESCUELA            4.
       ID_ENT             id_entF.
       NOM_ENT            $char19.
       ID_MOD             id_modF.
       MOD                $modF.
       GM                 $gmF.
       MARG_URB           marg_urF.
       ESTRATO            $char7.
       ENTEST             $char6.
       ALUMNO             5.
       ID_INSTR           $char16.
       SEXO               sexoF.
       EDAD               edadF.
       EDADC              edadcF.
       EDADN              edadnF.
       EDAD_AC            edad_acF.
       MES_NAC            mes_nacF.
       DOCENTE            docenteF.
       PCA_01             ca1_c19F.
       PCA_02             ca1_c19F.
       PCA_03             ca1_c19F.
       PCA_04             ca1_c19F.
       PCA_05             ca1_c19F.
       PCA_06             ca1_c19F.
       PCA_07             ca1_c19F.
       PCA_08             ca1_c19F.
       PCA_09             ca1_c19F.
       PCA_10             ca1_c19F.
       PCA_11             ca1_c19F.
       PCA_12             ca1_c19F.
       PCA_13             ca1_c19F.
       PCA_14             ca1_c19F.
       PCA_15             ca1_c19F.
       PCA_16             ca1_c19F.
       PCA_17             ca1_c19F.
       PCA_18             ca1_c19F.
       PCB_01             ca1_c19F.
       PCB_02             ca1_c19F.
       PCB_03             ca1_c19F.
       PCB_04             ca1_c19F.
       PCB_05             ca1_c19F.
       PCB_06             ca1_c19F.
       PCB_07             ca1_c19F.
       PCB_08             ca1_c19F.
       PCB_09             ca1_c19F.
       PCB_10             ca1_c19F.
       PCB_11             ca1_c19F.
       PCB_12             ca1_c19F.
       PCB_13             ca1_c19F.
       PCB_14             ca1_c19F.
       PCB_15             ca1_c19F.
       PCB_16             ca1_c19F.
       PCB_17             ca1_c19F.
       PCB_18             ca1_c19F.
       PCB_19             ca1_c19F.
       PCC_01             ca1_c19F.
       PCC_03             ca1_c19F.
       PCC_04             ca1_c19F.
       PCC_05             ca1_c19F.
       PCC_06             ca1_c19F.
       PCC_07             ca1_c19F.
       PCC_08             ca1_c19F.
       PCC_09             ca1_c19F.
       PCC_10             ca1_c19F.
       PCC_11             ca1_c19F.
       PCC_12             ca1_c19F.
       PCC_13             ca1_c19F.
       PCC_14             ca1_c19F.
       PCC_15             ca1_c19F.
       PCC_16             ca1_c19F.
       PCC_17             ca1_c19F.
       PCC_18             ca1_c19F.
       PCC_19             ca1_c19F.
   ;

/**************************************************************************
/*  Definicin de valores perdidos
/*   .N o N = No Administrado o no alcanzado.
/*   .M o M = Respuesta Mltiple.
/*   .S o S = Respuesta omitida (No contestado).
/*************************************************************************/
   IF  sexo = 8 THEN  sexo = .M;
   IF  edad_ac = 98 THEN  edad_ac = .M;
   IF  mes_nac = 98 THEN  mes_nac = .M;
   IF  GM = "9"  THEN  GM = .S;
   IF  GM = "NA"  THEN  GM = .S;
   IF  marg_urb = 7 THEN  marg_urb = .S;

   ARRAY perdidos1(3)  sexo edadc edadn;
   DO  i=1 TO 3;
         IF perdidos1{i}=9 THEN  perdidos1{i}= .S;
   END;

   ARRAY perdidos2(3)  edad edad_ac mes_nac;
   DO  i=1 TO 3;
         IF perdidos2{i}=99 THEN  perdidos2{i}= .S;
   END;

   IF  docente = 99999 THEN  docente = .S;

   ARRAY perdidos3(55)
                  PCA_01 PCA_02 PCA_03 PCA_04 PCA_05 PCA_06 PCA_07 PCA_08 PCA_09 PCA_10
                  PCA_11 PCA_12 PCA_13 PCA_14 PCA_15 PCA_16 PCA_17 PCA_18 PCB_01
                  PCB_02 PCB_03 PCB_04 PCB_05 PCB_06 PCB_07 PCB_08 PCB_09 PCB_10
                  PCB_11 PCB_12 PCB_13 PCB_14 PCB_15 PCB_16 PCB_17 PCB_18 PCB_19
                  PCC_01 PCC_03 PCC_04 PCC_05 PCC_06 PCC_07 PCC_08 PCC_09 PCC_10
                  PCC_11 PCC_12 PCC_13 PCC_14 PCC_15 PCC_16 PCC_17 PCC_18 PCC_19;
   DO  i=1 TO 55;
          IF perdidos3{i} = 5   THEN  perdidos3{i} = .N;
          IF perdidos3{i} = 6   THEN  perdidos3{i} = .N;
          IF perdidos3{i} = 7   THEN  perdidos3{i} = .N;
          IF perdidos3{i} = 8   THEN  perdidos3{i} = .M;
          IF perdidos3{i} = 9   THEN  perdidos3{i} = .S;
   END;

   drop i;
RUN;
